<?php
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Email_Subscribers_Starter' ) ) {

	class Email_Subscribers_Starter {

		public $starter_plugin_url;
		public $starter_plugin_path;

		public function __construct() {

			$this->starter_plugin_url  = untrailingslashit( plugins_url( '/', __FILE__ ) ) . '/';
			$this->starter_plugin_path = untrailingslashit( plugin_dir_path( __FILE__ ) );

			$this->load_dependencies();

			if ( ! is_admin() || ( defined( 'DOING_AJAX' ) && DOING_AJAX ) ) {
				$php_version = phpversion();
				if ( version_compare( $php_version, '5.4.0', '<' ) ) {
					if ( session_id() === '' && ! headers_sent() ) {
						session_start();
					}
				} else {
					if ( session_status() === PHP_SESSION_NONE && session_id() === '' && ! headers_sent() ) {
						session_start();
					}
				}
			}

			$last_updated_blocked_domains = get_option( 'ig_es_last_updated_blocked_domains', 0 );
			if ( 0 == $last_updated_blocked_domains || ( ( time() - $last_updated_blocked_domains ) > ( 7 * DAY_IN_SECONDS ) ) ) {
				Email_Subscribers_Utils::get_managed_domains_from_ig();
			}

			// ES integration include
			if ( is_file( $this->starter_plugin_path . '/starter-class-es-integrations.php' ) ) {
				include_once  $this->starter_plugin_path . '/starter-class-es-integrations.php' ;
				new ES_Integrations();
			}

			add_action( 'wp_enqueue_scripts', array( &$this, 'es_starter_load_scripts_styles' ), 12, 2 );
			add_action( 'admin_menu', array( &$this, 'remove_submenus' ) );

			// Enqueue admin js/css
			add_action( 'admin_enqueue_scripts', array( &$this, 'enqueue_admin_scripts' ) );

			add_filter( 'ig_es_after_form_fields', array( &$this, 'es_embed_captcha' ), 11, 2 );
			//Intermediate unsubscribe page
			add_action( 'ig_es_update_subscriber', array( &$this, 'ig_es_intermediate_unsubscribe_page' ), 10, 1 );

			add_filter( 'ig_es_validate_subscribers_data', array( &$this, 'es_validate_captcha' ) );
			add_filter( 'ig_es_show_wp_cron_notice', array( &$this, 'ig_es_show_wp_cron_notice' ) );

			//Add Mailers
			add_filter( 'ig_es_mailers', array( &$this, 'starter_mailers' ), 10 );
			add_filter( 'ig_es_accessible_sub_menus', array( &$this, 'get_accessible_submenus' ), 10, 1 );
			add_filter( 'ig_es_can_access', array( &$this, 'can_access_menu' ), 10, 2 );

			//add_filter( 'ig_es_email_sending_limit', array( &$this, 'es_get_email_sending_limit' ), 10, 2 );
			//add_filter( 'ig_es_email_sending_limit', array( &$this, 'es_bypass_cron_request' ), 10, 2 );

			//add_action( 'ig_es_after_settings_save', array( &$this, 'es_send_cron_data' ), 10, 1 );

			add_filter( 'ig_es_registered_settings', array( &$this, 'es_add_settings_fields' ), 20, 2 );
			add_filter( 'ig_es_before_save_settings', array( &$this, 'es_modify_settings' ), 10, 2 );

			//add_filter( 'ig_es_util_data', array( &$this, 'es_add_starter_task' ), 10, 2 );
			add_filter( 'ig_es_template_thumbnail', array( &$this, 'es_add_starter_badge' ), 10, 2 );

			//added user permission tab
			add_filter( 'ig_es_settings_tabs', array( &$this, 'es_user_permission_tab' ) );

			add_filter( 'ig_es_email_templates', array( &$this, 'es_get_starter_templates' ), 10, 1 );

			// Filter to add Starter Workflow Triggers
			add_filter( 'ig_es_workflow_triggers', array( &$this, 'register_workflow_triggers' ) );

			// Filter to add Starter Workflow Required Data Types
			add_filter( 'ig_es_data_types_includes', array( &$this, 'register_workflow_data_types' ) );

			// Filter to add Starter Workflow Required Variables
			add_filter( 'ig_es_workflow_variables', array( &$this, 'register_workflow_variables' ) );

			add_action( 'ig_es_add_additional_options', array( &$this, 'display_captcha' ), 10, 1 );

			// Filter to register services offered in starter version.
			add_filter( 'ig_es_services', array( &$this, 'register_services' ) );
			
			// Filter to get plugin plan
			add_filter( 'ig_es_plan', array( &$this, 'get_plan' ), 11 );
			
			add_action( 'wp_ajax_ig_es_disable_session_tracking', array( &$this, 'ajax_disable_session_tracking' ) );
			add_action( 'wp_ajax_nopriv_ig_es_disable_session_tracking', array( &$this, 'ajax_disable_session_tracking' ) );
			
			
			add_filter( 'ig_es_report_row_actions', array( &$this, 'add_report_pause_resume_action' ), 10, 2 );
			add_action( 'ig_es_campaign_column_status', array( &$this, 'add_broadcast_pause_resume_action' ), 10, 2 );
			add_action( 'wp_ajax_ig_es_pause_resume_report', array( &$this, 'pause_resume_report' ) );
		}

		/**
		 * Load the required dependencies for this plugin.
		 * 
		 * @since 4.6.6
		 */
		public function load_dependencies() {
			$files_to_load = array(
				//Load Starter & Pro files if exists
				'class-es-utils.php',
				
				'mailers/class-es-smtp-mailer.php',

				// Data Types from Starter version
				'workflows/data-types/class-es-data-type-comment.php',
				'workflows/data-types/class-es-data-type-wc-order.php',
				'workflows/data-types/class-es-data-type-edd-payment.php',
				'workflows/data-types/class-es-data-type-cf7-data.php',
				'workflows/data-types/class-es-data-type-wpforms-data.php',
				'workflows/data-types/class-es-data-type-ninja-forms-data.php',
				'workflows/data-types/class-es-data-type-give-data.php',
				'workflows/data-types/class-es-data-type-gravity-forms-data.php',
				'workflows/data-types/class-es-data-type-forminator-forms-data.php',

				// Workflow Variables.
				'workflows/variables/abstracts/abstract-price.php',
				'workflows/variables/abstracts/abstract-product-display.php',
				'workflows/variables/abstracts/abstract-datetime.php',
				'workflows/variables/abstracts/abstract-meta.php',
				
				// Triggers from Starter version
				'workflows/triggers/class-es-trigger-comment-added.php',
				'workflows/triggers/class-es-trigger-cf7-submitted.php',
				'workflows/triggers/class-es-trigger-wc-order-created.php',
				'workflows/triggers/class-es-trigger-wc-order-completed.php',
				'workflows/triggers/class-es-trigger-edd-purchase-completed.php',
				'workflows/triggers/class-es-trigger-wpforms-submitted.php',
				'workflows/triggers/class-es-trigger-ninja-forms-submitted.php',
				'workflows/triggers/class-es-trigger-give-donation-made.php',
				'workflows/triggers/class-es-trigger-gravity-forms-submitted.php',
				'workflows/triggers/class-es-trigger-forminator-forms-submitted.php',
			);

			foreach ( $files_to_load as $file ) {
				if ( is_file( $this->starter_plugin_path . '/' . $file ) ) {
					require_once $this->starter_plugin_path . '/' . $file;
				}
			}
		}

		/**
		 * Show cron notice?
		 *
		 * @param $show_notice
		 *
		 * @return bool
		 *
		 * @sinc 4.0.0
		 */
		public function ig_es_show_wp_cron_notice( $show_notice ) {
			$show_notice = false;

			return $show_notice;
		}

		/**
		 * Get Email Templates
		 *
		 * @param $templates
		 *
		 * @return mixed
		 *
		 * @since 4.0.0
		 *
		 * @modify 4.3.1
		 */
		public function es_get_starter_templates( $templates = array() ) {
			$template_files = glob( untrailingslashit( plugin_dir_path( __FILE__ ) ) . '/templates/*.php' );

			if ( is_array( $template_files ) && count( $template_files ) ) {

				foreach ( $template_files as $file ) {
					if ( is_file( $file ) && is_admin() ) {
						$file_name = basename( $file, '.php' );

						$templates[ $file_name ] = include $file;
					}
				}
			}

			return $templates;
		}

		/**
		 * Embed Captcha
		 *
		 * @since 4.0.0
		 *
		 * @modified 4.4.7 Enable Captcha with the form level
		 */
		public function es_embed_captcha( $form_orig_html = '', $data = array() ) {

			$form_html = '';

			$captcha = ! empty( $data['captcha'] ) ? $data['captcha'] : 'no';

			if ( 'yes' === $captcha ) {
				$form_html .= $this->get_captcha();
			}

			$form = $form_orig_html . '' . $form_html;
			return $form;
		}

		/**
		 * Get Captcha
		 *
		 * @return string
		 *
		 * @since 4.0.0
		 */
		public function get_captcha() {
			if ( empty( $_SESSION['captcha'] ) ) {
				$_SESSION['captcha'] = array();
			}
			$captcha_html = '';
			$random_a     = rand( 1, 9 );
			$random_b     = rand( 1, 9 );

			//Create Unique key for every captcha created for a form, using WP generate password function.
			$es_captcha_key = wp_generate_password( 10, false );

			$_SESSION['captcha'][ $es_captcha_key ] = $random_a + $random_b;

			$captcha_text = __( 'Are You a Human?', 'email-subscribers' );
			$captcha_text = apply_filters( 'ig_es_captcha_text', $captcha_text );

			$captcha_html .= "<div class='es_captcha es-field-wrap'><label>" . $captcha_text . ' ' . $random_a . ' + ' . $random_b . ' = ';
			$captcha_html .= "<br /><input class='es_form_field es_captcha_input' name='esfpx_es_captcha' type='number'>";
			$captcha_html .= "<input class='es_form_field es_captcha_key' value='" . $es_captcha_key . "' name='esfpx_es_captcha_key' type='hidden'></label>";
			$captcha_html .= '</div>';

			return $captcha_html;
		}

		/**
		 * Validate Captcha
		 *
		 * @param $data
		 *
		 * @return array
		 *
		 * @since 4.0.0
		 */
		public function es_validate_captcha( $data ) {

			$response = array( 'status' => 'SUCCESS' );

			$form_id   = ! empty( $data['esfpx_form_id'] ) ? $data['esfpx_form_id'] : 0;
			$form_type = ! empty( $data['form_type'] ) ? $data['form_type'] : '';

			$enable_captcha = ES_Common::get_captcha_setting( $form_id );

			// Check if captcha validation is enabled and it is not an external subscription form.
			if ( 'yes' === $enable_captcha && 'external' !== $form_type ) {

				$es_captcha_key = ! empty( $data['esfpx_es_captcha_key'] ) ? $data['esfpx_es_captcha_key'] : '';

				if ( ! empty( $es_captcha_key ) && ! empty( $_SESSION['captcha'][ $es_captcha_key ] ) && $_SESSION['captcha'][ $es_captcha_key ] == $data['esfpx_es_captcha'] ) {
					$response['status'] = 'SUCCESS';
				} else {
					$response = array( 'status' => 'ERROR', 'message' => 'es_invalid_captcha' );

					$response['captchaHtml'] = $this->get_captcha();
				}
			}

			return $response;
		}

		/**
		 * Register starter admin JS scripts.
		 * 
		 * @since 4.7.8
		 */
		public function enqueue_admin_scripts() {

			wp_register_script( 'es_starter_admin_js', $this->starter_plugin_url . 'assets/js/admin.js', array( 'jquery', 'jquery-ui-core' ), ES_PLUGIN_VERSION );

			wp_enqueue_script( 'es_starter_admin_js' );
		}

		/**
		 * Load JS/ CSS
		 *
		 * @since 3.5.x
		 */
		public function es_starter_load_scripts_styles() {

			
			wp_register_script( 'es_starter_main_js', $this->starter_plugin_url . 'assets/js/starter-main.js', array( 'jquery' ), ES_PLUGIN_VERSION, true );
			wp_enqueue_script( 'es_starter_main_js' );
			wp_register_style( 'es_starter_main_css', $this->starter_plugin_url . 'assets/css/starter-main.css', array(), ES_PLUGIN_VERSION, 'all' );
			wp_enqueue_style( 'es_starter_main_css' );
			
			$js_params = array();

			$show_opt_in_consent                       = get_option( 'ig_es_show_opt_in_consent', 'no' );
			$js_params['show_opt_in_consent']          = $show_opt_in_consent;
			$js_params['session_tracking_enabled']	   = IG_ES_WC_Session_Tracker::session_tracking_enabled() ? 'yes': 'no';
			$js_params['user_logged_in']               = is_user_logged_in() ? 'yes' : 'no';
			$js_params['consent_opt_in_message']       = get_option( 'ig_es_opt_in_consent_text', '' );
			$js_params['consent_opt_out_message']      = __( 'No Thanks', 'email-subscribers' );
			$js_params['conset_after_opt_out_message'] = __( 'You won\'t receive further emails from us, thank you!', 'email-subscribers' );
			$js_params['ajax_url']                     = admin_url( 'admin-ajax.php' );
			$js_params['security']                     = wp_create_nonce( 'ig-es-public-nonce' );

			wp_localize_script( 'es_starter_main_js', 'ig_es_starter_main_js_params', $js_params );
		}

		/**
		 * Bypass Cron Request
		 *
		 * @param $es_process_request
		 *
		 * @return bool
		 *
		 * @since 4.0.0
		 */
		public function es_bypass_cron_request( $es_process_request ) {
			if ( ! empty( $_GET['es_pro'] ) && 'true' !== $_GET['es_pro'] ) {
				$es_process_request = false;
			}

			return $es_process_request;
		}

		/**
		 * Get Email Sending Limit
		 *
		 * @param $es_email_limit
		 *
		 * @return mixed
		 *
		 * @since 4.0.0
		 */
		public function es_get_email_sending_limit( $es_email_limit ) {
			$es_email_limit = ! empty( $_SERVER['HTTP_X_ES_EMAIL_SENDING_LIMIT'] ) ? sanitize_text_field( $_SERVER['HTTP_X_ES_EMAIL_SENDING_LIMIT'] ) : $es_email_limit;

			return $es_email_limit;
		}

		/**
		 * Add Starter settings
		 *
		 * @param $fields
		 *
		 * @return mixed
		 *
		 * @sinc 4.0.0
		 */
		public function es_add_settings_fields( $fields ) {

			$smtp_host_defined 	         = ES()->is_const_defined( 'smtp', 'host' );
			$smtp_encryption_defined     = ES()->is_const_defined( 'smtp', 'encryption' );
			$smtp_port_defined           = ES()->is_const_defined( 'smtp', 'port' );
			$smtp_authentication_defined = ES()->is_const_defined( 'smtp', 'authentication' );
			$smtp_username_defined       = ES()->is_const_defined( 'smtp', 'username' );
			$smtp_password_defined       = ES()->is_const_defined( 'smtp', 'password' );

			// Add SMTP Settings
			$smtp_sub_fields = array(
				'ig_es_smtp_host' => array(
					'type'         => 'text',
					'options'      => false,
					'placeholder'  => '',
					'supplemental' => '',
					'default'      => '',
					'id'           => 'ig_es_mailer_settings[smtp][smtp_host]',
					'name'         => __( 'SMTP Host', 'email-subscribers' ),
					'desc'         => ( $smtp_host_defined ? ES()->get_const_set_message( 'smtp', 'host' ) : '' ) . '',
					'class'        => 'smtp',
					'disabled'     => $smtp_host_defined ? 'disabled' : '',
					'value'        => $smtp_host_defined ? '******************' : '',
				),

				'ig_es_smtp_encryption' => array(
					'type'         => 'select',
					'options'      => array( 'none' => __( 'None', 'email-subscribers' ), 'ssl' => __( 'SSL', 'email-subscribers' ), 'tls' => __( 'TLS', 'email-subscribers' ) ),
					'placeholder'  => '',
					'supplemental' => '',
					'default'      => '',
					'id'           => 'ig_es_mailer_settings[smtp][smtp_encryption]',
					'name'         => __( 'Encryption', 'email-subscribers' ),
					'desc'         => ( $smtp_encryption_defined ? ES()->get_const_set_message( 'smtp', 'encryption' ) : '' ) . '',
					'class'        => 'smtp',
					'disabled'     => $smtp_encryption_defined ? 'disabled' : '',
					'value'        => $smtp_encryption_defined ? ES()->get_const_value( 'smtp', 'encryption' ) : '',
				),

				'ig_es_smtp_port' => array(
					'type'         => 'text',
					'options'      => false,
					'placeholder'  => '',
					'supplemental' => '',
					'default'      => '',
					'id'           => 'ig_es_mailer_settings[smtp][smtp_port]',
					'name'         => __( 'SMTP Port', 'email-subscribers' ),
					'desc'         => ( $smtp_port_defined ? ES()->get_const_set_message( 'smtp', 'port' ) : '' ) . '',
					'class'        => 'smtp',
					'disabled'     => $smtp_port_defined ? 'disabled' : '',
					'value'        => $smtp_port_defined ? '******************' : '',
				),

				'ig_es_smtp_authentication' => array(
					'type'         => 'select',
					'options'      => array( 'no' => __( 'No', 'email-subscribers' ), 'yes' => __( 'Yes', 'email-subscribers' ) ),
					'placeholder'  => '',
					'supplemental' => '',
					'default'      => '',
					'id'           => 'ig_es_mailer_settings[smtp][smtp_authentication]',
					'name'         => __( 'Authentication', 'email-subscribers' ),
					'desc'         => ( $smtp_authentication_defined ? ES()->get_const_set_message( 'smtp', 'authentication' ) : '' ),
					'class'        => 'smtp',
					'disabled'     => $smtp_authentication_defined ? 'disabled' : '',
					'value'        => $smtp_authentication_defined ? ES()->get_const_value( 'smtp', 'authentication' ) : '',
				),

				'ig_es_smtp_username' => array(
					'type'         => 'text',
					'options'      => false,
					'placeholder'  => '',
					'supplemental' => '',
					'default'      => '',
					'id'           => 'ig_es_mailer_settings[smtp][smtp_username]',
					'name'         => __( 'SMTP Username', 'email-subscribers' ),
					'desc'         => ( $smtp_username_defined ? ES()->get_const_set_message( 'smtp', 'username' ) : '' ),
					'class'        => 'smtp',
					'disabled'     => $smtp_username_defined ? 'disabled' : '',
					'value'        => $smtp_username_defined ? '******************' : '',
				),

				'ig_es_smtp_password' => array(
					'type'         => $smtp_password_defined ? 'text' : 'password',
					'options'      => false,
					'placeholder'  => '',
					'supplemental' => '',
					'default'      => '',
					'id'           => 'ig_es_mailer_settings[smtp][smtp_password]',
					'name'         => __( 'SMTP Password', 'email-subscribers' ),
					'desc'         => ( $smtp_password_defined ? ES()->get_const_set_message( 'smtp', 'password' ) : '' ) . '',
					'class'        => 'smtp',
					'disabled'     => $smtp_password_defined ? 'disabled' : '',
					'value'        => $smtp_password_defined ? '******************' : '',
				),

			);
			$fields['email_sending']['ig_es_mailer_settings']['sub_fields'] = array_merge( $fields['email_sending']['ig_es_mailer_settings']['sub_fields'], $smtp_sub_fields );

			$fake_domains['ig_es_enable_known_attackers_domains'] = array(
				'id'      => 'ig_es_enable_known_attackers_domains',
				'name'    => __( 'Block known attackers', 'email-subscribers' ),
				'info'    => __( 'Stop spam bot attacker domains from signing up. Icegram maintains a blacklist of such attackers and enabling this option will keep the blacklist updated.', 'email-subscribers' ),
				'type'    => 'checkbox',
				'default' => 'yes'
			);

			$managed_blocked_domains['ig_es_enable_disposable_domains'] = array(
				'id'      => 'ig_es_enable_disposable_domains',
				'name'    => __( 'Block temporary / fake emails', 'email-subscribers' ),
				'info'    => __( 'Plenty of sites provide disposable / fake / temporary email addresses. People use them when they don\'t want to give you their real email. Block such emails to keep your list clean. Turning this on will update the blacklist automatically.', 'email-subscribers' ),
				'type'    => 'checkbox',
				'default' => 'yes'
			);

			//add captcha setting
			$field_captcha['enable_captcha'] = array(
				'id'      => 'ig_es_enable_captcha',
				'name'    => __( 'Enable Captcha', 'email-subscribers' ),
				'info'    => __( 'Prevent bot signups even further. Set default captcha option for new subscription forms.', 'email-subscribers' ),
				'type'    => 'checkbox',
				'default' => 'no'
			);

			$fields['security_settings'] = array_merge( $fields['security_settings'], $fake_domains, $managed_blocked_domains, $field_captcha );

			$fields['user_roles'] = array(
				'ig_es_user_roles' => array(
					'id'   => 'ig_es_user_roles',
					'name' => '',
					'type' => 'html',
					'html' => $this->render_user_permissions_settings_fields()
				)
			);

			$field_comment_consent                         = array();
			$field_comment_consent['ig_es_opt_in_consent'] = array(
				'id'         => 'ig_es_opt_in_consent',
				'name'       => __( 'Nudge people to subscribe while leaving a comment or placing an order?', 'email-subscribers' ),
				'info'       => __( 'Adds a checkbox to subscribe when people post a comment or checkout (if you&rsquo;re using WooCommerce).', 'email-subscribers' ),
				'sub_fields' => array(
					'ig_es_show_opt_in_consent' => array(
						'id'      => 'ig_es_show_opt_in_consent',
						'name'    => '',
						'info'    => __( '(toggle to enable this)', 'email-subscribers' ),
						'type'    => 'checkbox',
						'default' => 'yes'
					),
					'ig_es_opt_in_consent_text' => array(
						'type'         => 'textarea',
						'options'      => false,
						'placeholder'  => __( 'Opt-in consent message text', 'email-subscribers' ),
						'supplemental' => '',
						'default'      => '',
						'id'           => 'ig_es_opt_in_consent_text',
						'name'         => __( 'Opt-in consent text', 'email-subscribers' ),
					),
				)
			);

			$fields['general'] = ig_es_array_insert_after( $fields['general'], 'ig_es_track_utm', $field_comment_consent );

			//option to show integrmediate unsubscribe page
			$field_unsub['ig_es_intermediate_unsubscribe_page'] = array(
				'id'      => 'ig_es_intermediate_unsubscribe_page',
				'name'    => __( 'Allow user to select list(s) while unsubscribe', 'email-subscribers' ),
				'info'    => __( 'Enabling this will let users unsubscribe from multiple lists at once. (We recommend keeping it enabled)', 'email-subscribers'),
				'type'    => 'checkbox',
				'default' => 'no'
			);

			$fields['general'] = array_slice( $fields['general'], 0, 7, true ) + $field_unsub + array_slice( $fields['general'], 7, count( $fields['general'] ) - 7, true );

			return $fields;
		}

		/**
		 * Modify User Roles settings
		 *
		 * @param $options
		 *
		 * @return mixed
		 *
		 * @since 4.2.0
		 */
		public function es_modify_settings( $options ) {
			$option_fields = array(
				'ig_es_enable_captcha',
				'ig_es_enable_known_attackers_domains',
				'ig_es_enable_disposable_domains',
				'ig_es_intermediate_unsubscribe_page',
				'ig_es_show_opt_in_consent'
			);

			foreach ( $option_fields as $option ) {
				if ( ! isset( $options[ $option ] ) ) {
					$options[ $option ] = 'no';
				}
			}

			//save admin disabled settings
			$options['ig_es_user_roles']['audience']['administrator']  = 'yes';
			$options['ig_es_user_roles']['forms']['administrator']     = 'yes';
			$options['ig_es_user_roles']['reports']['administrator']   = 'yes';
			$options['ig_es_user_roles']['sequences']['administrator'] = 'yes';
			$options['ig_es_user_roles']['campaigns']['administrator'] = 'yes';
			$options['ig_es_user_roles']['workflows']['administrator'] = 'yes';

			return $options;
		}

		/**
		 * Add Tasks to run on server
		 *
		 * @param $data
		 *
		 * @return mixed
		 *
		 * @since 3.5.0
		 */
		public function es_add_starter_task( $data ) {
			$meta            = ! empty( $data['campaign_id'] ) ? ES()->campaigns_db->get_campaign_meta_by_id( $data['campaign_id'] ) : '';
			$data['html']    = $data['content'];
			$data['css']     = ! empty( $meta['es_custom_css'] ) ? $meta['es_custom_css'] : get_post_meta( $data['tmpl_id'], 'es_custom_css', true );
			$data['tasks'][] = 'css-inliner';

			return $data;
		}

		/**
		 * Add Starter badge
		 *
		 * @param $es_template_thumbnail
		 *
		 * @return string
		 *
		 * @sinc 4.1.0
		 */
		public function es_add_starter_badge( $es_template_thumbnail ) {
			$es_template_thumbnail = ( $es_template_thumbnail ) ? $es_template_thumbnail . '<img style="vertical-align:top;margin-left:-2em;height:25px;width:25px" src="' . $this->starter_plugin_url . 'assets/images/ribbon.png"/>' : $es_template_thumbnail;

			return $es_template_thumbnail;
		}

		/**
		 * Add User Roles tab in settings
		 *
		 * @param $es_settings_tabs
		 *
		 * @return mixed
		 *
		 * @since 4.2.0
		 */
		public function es_user_permission_tab( $es_settings_tabs ) {
			$es_settings_tabs['user_roles'] = array( 'icon' => '<svg class="w-6 h-6 inline -mt-1.5" fill="none" stroke="currentColor" viewBox="0 0 24 24" xmlns="http://www.w3.org/2000/svg"><path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M17 20h5v-2a3 3 0 00-5.356-1.857M17 20H7m10 0v-2c0-.656-.126-1.283-.356-1.857M7 20H2v-2a3 3 0 015.356-1.857M7 20v-2c0-.656.126-1.283.356-1.857m0 0a5.002 5.002 0 019.288 0M15 7a3 3 0 11-6 0 3 3 0 016 0zm6 3a2 2 0 11-4 0 2 2 0 014 0zM7 10a2 2 0 11-4 0 2 2 0 014 0z"></path></svg>', 'name' => __( 'Access Control', 'email-subscribers' ) );

			return $es_settings_tabs;
		}

		/**
		 * Render User Permission Settings
		 *
		 * @return false|string
		 *
		 * @since 4.2.0
		 */
		public function render_user_permissions_settings_fields() {
			$wp_roles   = new WP_Roles();
			$roles      = $wp_roles->get_names();
			$user_roles = get_option( 'ig_es_user_roles' );
			$es_menus   = array(
				'audience',
				'forms',
				'campaigns',
				'reports',
				'sequences',
				'workflows',
			);
			ob_start();
			?>
			<p class="pb-2 text-sm font-normal text-gray-500"><?php echo esc_html__('You can allow different user roles access to different operations within Email Subscribers plugin. Please select which roles should have what access below.', 'email-subscribers' ); ?> </p>
			<table class="min-w-full rounded-lg">
				<thead>
				<tr class="bg-gray-100 leading-4 text-gray-500 tracking-wider">
					<th class="pl-10 py-4 text-left font-semibold text-sm"><?php echo esc_html__( 'Roles', 'email-subscribers' ); ?></th>
					<th class="px-2 py-4 text-center font-semibold text-sm"><?php echo esc_html__( 'Audience', 'email-subscribers' ); ?></th>
					<th class="px-2 py-4 text-center font-semibold text-sm"><?php echo esc_html__( 'Forms', 'email-subscribers' ); ?></th>
					<th class="px-2 py-4 text-center font-semibold text-sm"><?php echo esc_html__( 'Campaigns', 'email-subscribers' ); ?></th>
					<th class="px-2 py-4 text-center font-semibold text-sm"><?php echo esc_html__( 'Reports', 'email-subscribers' ); ?></th>
					<th class="px-2 py-4 text-center font-semibold text-sm"><?php echo esc_html__( 'Sequences', 'email-subscribers' ); ?></th>
					<th class="px-2 py-4 text-center font-semibold text-sm"><?php echo esc_html__( 'Workflows', 'email-subscribers' ); ?></th>
				</tr>
				</thead>
				<tbody class="bg-white">
				<?php 
				foreach ( $roles as $role => $value ) {
					$disabled = ( 'administrator' === $role ) ? 'disabled' : '';
					?>
					<tr class="border-b border-gray-200">
						<td class="pl-8 py-4 ">
							<div class="flex items-center">
								<div class="flex-shrink-0">
									<span class="text-sm leading-5 font-medium text-center text-gray-800"><?php echo esc_html( $value ); ?></span>
								</div>
							</div>
						</td>
						<?php
						foreach ( $es_menus as $menu ) {
							if ( 'administrator' === $role ) {
								$checked = 'yes';
							} else {
								if ( ! empty( $user_roles[$menu][$role] ) && 'yes' === $user_roles[$menu][$role] ) {
									$checked = 'yes';
								} else {
									$checked = 'no';
								}
							}
							?>
							<td class="whitespace-no-wrap text-center">
								<input type="checkbox" name="ig_es_user_roles[<?php echo esc_attr( $menu ); ?>][<?php echo esc_attr( $role ); ?>]" <?php echo esc_attr( $disabled ); ?><?php checked( 'yes', $checked ); ?> value="yes" class=" form-checkbox text-indigo-600">
							</td>
							<?php
						}
						?>
					</tr>
					<?php
				}
				?>
				</tbody>
			</table>

			<?php
			$html = ob_get_clean();

			return $html;
		}

		/**
		 * Remove ES Submenus based on permission
		 *
		 * @since 4.2.0
		 */
		public function remove_submenus() {
			$user_roles         = get_option( 'ig_es_user_roles', array() );
			$current_user       = wp_get_current_user();
			$current_user_roles = $current_user->roles;

			if ( empty( $user_roles ) ) {
				return;
			}

			// Is Administrator? Enable everything.
			if ( in_array( 'administrator', $current_user_roles ) ) {
				return;
			} else {

				// If not administrator? Remove settings menu
				// Currently, we are showing settings only to administrator
				remove_submenu_page( 'es_dashboard', 'es_settings' );
			}

			$enable_es_menu = false;
			$sub_menus      = array(

				'campaigns' => array(
					array( 'menu_slug' => 'es_dashboard', 'submenu_slug' => 'es_campaigns' ),
					array( 'menu_slug' => 'es_dashboard', 'submenu_slug' => 'es_template_preview' ),
					array( 'menu_slug' => 'es_dashboard', 'submenu_slug' => 'es_notifications' ),
					array( 'menu_slug' => 'es_dashboard', 'submenu_slug' => 'es_newsletters' )
				),

				'forms' => array(
					array( 'menu_slug' => 'es_dashboard', 'submenu_slug' => 'es_forms' )
				),

				'audience' => array(
					array( 'menu_slug' => 'es_dashboard', 'submenu_slug' => 'es_subscribers' ),
					array( 'menu_slug' => 'es_dashboard', 'submenu_slug' => 'es_lists' )
				),

				'reports'   => array(
					array( 'menu_slug' => 'es_dashboard', 'submenu_slug' => 'es_reports' )
				),
				'sequences' => array(
					array( 'menu_slug' => 'es_dashboard', 'submenu_slug' => 'es_sequences' )
				)
			);

			foreach ( $sub_menus as $key => $sub_menu ) {
				if ( ! empty( $user_roles[ $key ] ) && count( array_intersect( $current_user_roles, array_keys( $user_roles[ $key ] ) ) ) <= 0 ) {
					if ( is_array( $sub_menu ) && count( $sub_menu ) > 0 ) {
						foreach ( $sub_menu as $data ) {
							remove_submenu_page( $data['menu_slug'], $data['submenu_slug'] );
						}
					}
				} else {
					$enable_es_menu = true;
				}
			}

			// Don't have access to even a single submenu?
			// Remove ES main menu as well.
			if ( false == $enable_es_menu ) {
				remove_menu_page( 'es_dashboard' );
			}

		}

		/**
		 * Allow user to select the list from which they want to unsubscribe
		 *
		 * @since 4.2.0
		 */
		public function ig_es_intermediate_unsubscribe_page( $contact_id = 0 ) {
			$ig_es_intermediate_unsubscribe_page = get_option( 'ig_es_intermediate_unsubscribe_page', 'no' );

			// Enable?
			if ( 'yes' === $ig_es_intermediate_unsubscribe_page && ! empty( $contact_id ) ) {
				global $wp;
				$get    = ig_es_get_request_data();
				$action = home_url( add_query_arg( $get, $wp->request ) );
				$action = add_query_arg( 'list_selected', 1, $action );
				$hash   = ig_es_get_request_data( 'hash' );

				if ( ! empty( $hash ) ) {
					$data        = ig_es_decode_request_data( $hash );
					$email       = ! empty( $data['email'] ) ? $data['email']                  : '';
				}

				$lists = ES()->lists_contacts_db->get_list_ids_by_contact( $contact_id );

				$list_contact_status_map = ES()->lists_contacts_db->get_list_contact_status_map( $contact_id );
				if ( ! empty( $lists ) && ! empty( $list_contact_status_map ) && in_array( 'subscribed', $list_contact_status_map ) ) {
					wp_register_style( 'tailwind', ES_PLUGIN_URL . 'lite/admin/dist/main.css', array(), ES_PLUGIN_VERSION, 'all' );
					$es_wp_styles = wp_styles();
					$site_name    = get_bloginfo( 'name' );
					?>
					<!DOCTYPE html>
					<html <?php language_attributes(); ?>>
						<head>
							<meta charset="<?php bloginfo( 'charset' ); ?>">
							<meta name="viewport" content="width=device-width, initial-scale=1">
							<title><?php echo esc_html__( 'Unsubscribe', 'email-subscribers' ); ?> - <?php echo esc_html( $site_name ); ?></title>
							<?php
								$es_wp_styles->do_item( 'tailwind' );
							?>
							<script type="text/javascript">
								function validateForm() {
									var checkboxs = document.getElementsByClassName("ig_es_list_checkbox");
									var okay = false;
									for (var i = 0, l = checkboxs.length; i < l; i++) {
										if (checkboxs[i].checked) {
											okay = true;
											break;
										}
									}
									if (!okay) {
										alert( '<?php echo esc_js( __( 'Please select a list to unsubscribe', 'email-subscribers' ) ); ?>' );
										return false;
									}
								}

								function checkAll(ele) {
									var checkboxes = document.getElementsByTagName('input');
									if (ele.checked) {
										for (var i = 0; i < checkboxes.length; i++) {
											if (checkboxes[i].type == 'checkbox') {
												checkboxes[i].checked = true;
											}
										}
									} else {
										for (var i = 0; i < checkboxes.length; i++) {
											console.log(i)
											if (checkboxes[i].type == 'checkbox') {
												checkboxes[i].checked = false;
											}
										}
									}
								}

							</script>
							<style type="text/css">
								.ig_es_form_wrapper {
									width: 30%;
									margin: 0 auto;
									border: 2px #e8e3e3 solid;
									padding: 0.9em;
									border-radius: 5px;
								}

								.ig_es_form_heading {
									font-size: 1.3em;
									line-height: 1.5em;
									margin-bottom: 0.25rem;
								}

								.ig_es_list_checkbox {
									margin-right: 0.5em;
								}

								.ig_es_submit {
									color: #FFFFFF !important;
									border-color: #03a025 !important;
									background: #03a025 !important;
									box-shadow: 0 1px 0 #03a025;
									font-weight: bold;
									height: 2.4em;
									line-height: 1em;
									cursor: pointer;
									border-width: 1px;
									border-style: solid;
									-webkit-appearance: none;
									border-radius: 3px;
									white-space: nowrap;
									box-sizing: border-box;
									font-size: 1em;
									padding: 0 2em;
									margin-top: 1em;
								}

								.ig_es_submit:hover {
									color: #FFF !important;
									background: #0AAB2E !important;
									border-color: #0AAB2E !important;
								}

								.ig_es_form_wrapper hr {
									display: block;
									height: 1px;
									border: 0;
									border-top: 1px solid #ccc;
									margin: 1em 0;
									padding: 0;
								}

							</style>
						</head>
						<body>
							<div class="min-h-screen px-4 pt-10 pb-12 mx-auto bg-gray-100 sm:px-6 lg:px-8">
								<section class="bg-white mt-12 py-7 shadow-md sm:rounded-lg mx-auto sm:w-2/4 xl:w-6/12">
								<div class="flex">
									<div class="w-full pl-6 pr-6 leading-6">
										<form action="<?php echo esc_attr( $action ); ?>" method="post" id="ig_es_unsubscribe_list_form" class="mb-0" onsubmit="return validateForm()">
											<?php wp_nonce_field( 'ig-es-unsubscribe-nonce', 'ig_es_unsubscribe_nonce' ); ?>
											<?php
											do_action( 'ig_es_unsubscribe_form_after_start' );
											?>
											<?php
											if ( ! empty( $email ) ) {
												?>
												<div class="ig_es_unsubscribe_header text-center pb-2">
													<span class="block text-xl font-medium text-gray-600"><?php echo esc_html( $email ); ?></span>
													<span>
														<?php
															echo esc_html__( 'is subscribed to our mailing list(s).', 'email-subscribers' );
														?>
													</span>
												</div>
												<!-- <hr/> -->
												<?php
											}
											?>
											<div class="ig_es_select_unsubscribe_list pt-3 pb-4 border-t border-gray-150 px-3">
												<div class="ig_es_form_heading"><p class="text-base tracking-wide text-gray-600 font-medium"><?php echo esc_html__( 'Unsubscribe from below mailing list(s)', 'email-subscribers' ); ?></p></div>
												<label class="text-gray-700 text-base tracking-wide"><input class="ig_es_list_checkbox form-checkbox" type="checkbox" onchange="checkAll(this)"><?php echo esc_html__( 'Unsubscribe from all the lists', 'email-subscribers' ); ?></input></label><br/>
												<?php
												foreach ( $lists as $list ) {
													if ( array_key_exists( $list, $list_contact_status_map ) && 'subscribed' == $list_contact_status_map[ $list ] ) {
														$list_name = ES()->lists_db->get_list_name_by_id( $list );
														echo '<label class="text-gray-700 text-base tracking-wide"><input class="ig_es_list_checkbox form-checkbox vertical-align" type="checkbox" name="unsubscribe_lists[]" value="' . esc_attr( $list ) . '">' . esc_html( $list_name ) . '</input></label><br/>';
													}
												}
												?>
											</div>
											<?php
											do_action( 'ig_es_unsubscribe_form_before_end' );
											?>
											<input type="hidden" name="submitted" value="submitted">
											<input class="ml-3 mt-4 rounded-md border border-transparent px-4 py-2 bg-white text-sm leading-5 font-medium text-white bg-indigo-600  transition ease-in-out duration-150 hover:bg-indigo-500 focus:ring-4 focus:ring-indigo-500 cursor-pointer" type="submit" value="<?php echo esc_attr__( 'Unsubscribe', 'email-subscribers' ); ?>">
										</form>
										</div>
										</div>
								</section>
							</div>
						</body>
					</html>
					<?php
					die();
				} else {
					return;
				}
			}
		}

		/**
		 * Add Support For SMTP
		 *
		 * @param $mailers
		 *
		 * @return mixed
		 *
		 * @since 4.2.0
		 */
		public function starter_mailers( $mailers ) {
			$mailers['smtp'] = array( 'name' => 'SMTP', 'logo' => ES_PLUGIN_URL . 'lite/admin/images/smtp.png' );

			return $mailers;
		}

		/**
		 * Check whether user hae permission to access
		 *
		 * @param $can_access
		 * @param $page
		 *
		 * @return bool
		 *
		 * @since 4.2.2
		 */
		public function can_access_menu( $can_access, $page ) {
			$accessible_menus = $this->get_accessible_submenus();

			if ( in_array( $page, $accessible_menus ) ) {
				$can_access = true;
			}

			return $can_access;
		}

		/**
		 * Get accessible submenus
		 *
		 * @param $menus
		 *
		 * @return array
		 *
		 * @since 4.2.2
		 */
		public function get_accessible_submenus( $menus = array() ) {
			$permissions        = get_option( 'ig_es_user_roles', array() );
			$current_user       = wp_get_current_user();
			$current_user_roles = $current_user->roles;

			if ( empty( $permissions ) ) {
				return $menus;
			}

			if ( count( $permissions ) > 0 ) {
				foreach ( $permissions as $menu => $permission ) {
					if ( count( array_intersect( $current_user_roles, array_keys( $permission ) ) ) > 0 ) {
						$menus[] = $menu;
					}
				}

				$menus = array_unique( $menus );
			}

			return $menus;
		}

		/**
		 * Register workflow triggers
		 *
		 * @param array $workflow_triggers
		 *
		 * @return array $workflow_triggers
		 *
		 * @since 4.4.1
		 */
		public function register_workflow_triggers( $workflow_triggers = array() ) {

			global $ig_es_tracker;

			if ( empty( $workflow_triggers ) || ! is_array( $workflow_triggers ) ) {
				$workflow_triggers = array();
			}

			$workflow_triggers['ig_es_comment_added'] = 'ES_Trigger_Comment_Added';

			$active_plugins = $ig_es_tracker::get_active_plugins();

			// Show only if WooCommerce is installed & activated
			$woocommerce_plugin = 'woocommerce/woocommerce.php';
			if ( in_array( $woocommerce_plugin, $active_plugins, true ) ) {
				$workflow_triggers['ig_es_wc_order_completed'] = 'ES_Trigger_WC_Order_Completed';
				$workflow_triggers['ig_es_wc_order_created']   = 'ES_Trigger_WC_Order_Created';
			}

			// Show only if EDD is installed & activated
			$edd_plugin = 'easy-digital-downloads/easy-digital-downloads.php';
			if ( in_array( $edd_plugin, $active_plugins, true ) ) {
				$workflow_triggers['ig_es_edd_complete_purchase'] = 'ES_Trigger_EDD_Purchase_Completed';
			}

			// Show only if Contact Form 7 is installed & activated
			$cf7_plugin = 'contact-form-7/wp-contact-form-7.php';
			if ( in_array( $cf7_plugin, $active_plugins, true ) ) {
				$workflow_triggers['ig_es_cf7_submitted'] = 'ES_Trigger_CF7_Submitted';
			}

			// Show only if WP Forms plugin is installed & activated
			$wpforms_lite_plugin = 'wpforms-lite/wpforms.php';
			$wpforms_plugin      = 'wpforms/wpforms.php';
			if ( in_array( $wpforms_lite_plugin, $active_plugins, true ) || in_array( $wpforms_plugin, $active_plugins, true ) ) {
				$workflow_triggers['ig_es_wpforms_submitted'] = 'ES_Trigger_WPForms_Submitted';
			}

			// Show only if Give is installed & activated
			$give_plugin = 'give/give.php';
			if ( in_array( $give_plugin, $active_plugins, true ) ) {
				$workflow_triggers['ig_es_give_donation_made'] = 'ES_Trigger_Give_Donation_Made';
			}

			// Show only if Ninja Forms is installed & activated
			$ninja_forms_plugin = 'ninja-forms/ninja-forms.php';
			if ( in_array( $ninja_forms_plugin, $active_plugins, true ) ) {
				$workflow_triggers['ig_es_ninja_forms_submitted'] = 'ES_Trigger_Ninja_Forms_Submitted';
			}

			//Show only if Gravity Form is installed & activated
			$gravity_forms_plugin = 'gravityforms/gravityforms.php';
			if ( in_array( $gravity_forms_plugin, $active_plugins, true ) ) {
				$workflow_triggers['ig_es_gravity_forms_submitted'] = 'ES_Trigger_Gravity_Forms_Submitted';
			}

			//Show only if Forminator Plugin is installed & activated
			$forminator_plugin = 'forminator/forminator.php';
			if ( in_array( $forminator_plugin, $active_plugins, true ) ) {
				$workflow_triggers['ig_es_forminator_forms_submitted'] = 'ES_Trigger_Forminator_Forms_Submitted';
			}

			return $workflow_triggers;
		}

		/**
		 * Register workflow data types
		 *
		 * @param array $data_types
		 *
		 * @return array $data_types
		 *
		 * @since 4.4.1
		 */
		public function register_workflow_data_types( $data_types = array() ) {

			global $ig_es_tracker;

			if ( empty( $data_types ) || ! is_array( $data_types ) ) {
				$data_types = array();
			}

			$active_plugins = $ig_es_tracker::get_active_plugins();

			$data_types['comment'] = 'ES_Data_Type_Comment';

			// Add only if WooCommerce is installed & activated
			$woocommerce_plugin = 'woocommerce/woocommerce.php';
			if ( in_array( $woocommerce_plugin, $active_plugins, true ) ) {
				$data_types['wc_order'] = 'ES_Data_Type_WC_Order';
			}

			// Add only if EDD is installed & activated
			$edd_plugin = 'easy-digital-downloads/easy-digital-downloads.php';
			if ( in_array( $edd_plugin, $active_plugins, true ) ) {
				$data_types['edd_payment'] = 'ES_Data_Type_EDD_Payment';
			}

			// Add only if Contact Form 7 is installed & activated
			$cf7_plugin = 'contact-form-7/wp-contact-form-7.php';
			if ( in_array( $cf7_plugin, $active_plugins, true ) ) {
				$data_types['cf7_data'] = 'ES_Data_Type_CF7_Data';
			}

			// Add only if WP Forms is installed & activated
			$wpforms_lite_plugin = 'wpforms-lite/wpforms.php';
			$wpforms_plugin      = 'wpforms/wpforms.php';
			if ( in_array( $wpforms_lite_plugin, $active_plugins, true ) || in_array( $wpforms_plugin, $active_plugins, true ) ) {
				$data_types['wpforms_data'] = 'ES_Data_Type_WPForms_Data';
			}

			// Add only if Ninja Forms is installed & activated
			$ninja_forms_plugin = 'ninja-forms/ninja-forms.php';
			if ( in_array( $ninja_forms_plugin, $active_plugins, true ) ) {
				$data_types['ninja_forms_data'] = 'ES_Data_Type_Ninja_Forms_Data';
			}

			// Add only if Give is installed & activated
			$give_plugin = 'give/give.php';
			if ( in_array( $give_plugin, $active_plugins, true ) ) {
				$data_types['give_data'] = 'ES_Data_Type_Give_Data';
			}

			// Add only if Gravity Form is installed & activated
			$gravity_forms_plugin = 'gravityforms/gravityforms.php';
			if ( in_array( $gravity_forms_plugin, $active_plugins, true ) ) {
				$data_types['gravity_forms_data'] = 'ES_Data_Type_Gravity_Forms_Data';
			}

			// Add only if Forminator plugin is installed & activated
			$forminator_plugin = 'forminator/forminator.php';
			if ( in_array( $forminator_plugin, $active_plugins, true ) ) {
				$data_types['forminator_forms_data'] = 'ES_Data_Type_Forminator_Forms_Data';
			}

			return $data_types;
		}

		/**
		 * Register workflow variables
		 *
		 * @param array $variables
		 *
		 * @return array $variables
		 *
		 * @since 4.6.9
		 */
		public function register_workflow_variables( $variables = array() ) {

			global $ig_es_tracker;

			if ( empty( $variables ) || ! is_array( $variables ) ) {
				$variables = array();
			}

			$active_plugins = $ig_es_tracker::get_active_plugins();

			// Show only if WooCommerce is installed & activated
			$woocommerce_plugin = 'woocommerce/woocommerce.php';
			if ( in_array( $woocommerce_plugin, $active_plugins, true ) ) {

				$variables = array(
					'wc_order' => array(
						'id'                      => $this->starter_plugin_path . '/workflows/variables/wc-order-id.php',
						'admin_url'               => $this->starter_plugin_path . '/workflows/variables/wc-order-admin-url.php',
						'billing_email'           => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-email.php',
						'billing_first_name'      => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-first-name.php',
						'billing_last_name'       => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-last-name.php',
						'billing_address'         => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-address.php',
						'billing_address_line_1'  => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-address-line-1.php',
						'billing_address_line_2'  => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-address-line-2.php',
						'billing_phone'           => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-phone.php',
						'billing_city'            => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-city.php',
						'billing_company_name'    => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-company-name.php',
						'billing_country'         => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-country.php',
						'billing_postcode'        => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-postcode.php',
						'billing_state'           => $this->starter_plugin_path . '/workflows/variables/wc-order-billing-state.php',
						'customer_details'        => $this->starter_plugin_path . '/workflows/variables/wc-order-customer-details.php',
						'customer_note'           => $this->starter_plugin_path . '/workflows/variables/wc-order-customer-note.php',
						'items_count'             => $this->starter_plugin_path . '/workflows/variables/wc-order-items-count.php',
						'meta'                    => $this->starter_plugin_path . '/workflows/variables/wc-order-meta.php',
						'number'                  => $this->starter_plugin_path . '/workflows/variables/wc-order-number.php',
						'payment_method'          => $this->starter_plugin_path . '/workflows/variables/wc-order-payment-method.php',
						'payment_url'             => $this->starter_plugin_path . '/workflows/variables/wc-order-payment-url.php',
						'shipping_address'        => $this->starter_plugin_path . '/workflows/variables/wc-order-shipping-address.php',
						'shipping_address_line_1' => $this->starter_plugin_path . '/workflows/variables/wc-order-shipping-address-line-1.php',
						'shipping_address_line_2' => $this->starter_plugin_path . '/workflows/variables/wc-order-shipping-address-line-2.php',
						'shipping_city'           => $this->starter_plugin_path . '/workflows/variables/wc-order-shipping-city.php',
						'shipping_company_name'   => $this->starter_plugin_path . '/workflows/variables/wc-order-shipping-company-name.php',
						'shipping_country'        => $this->starter_plugin_path . '/workflows/variables/wc-order-shipping-country.php',
						'shipping_first_name'     => $this->starter_plugin_path . '/workflows/variables/wc-order-shipping-first-name.php',
						'shipping_last_name'      => $this->starter_plugin_path . '/workflows/variables/wc-order-shipping-last-name.php',
						'shipping_postcode'       => $this->starter_plugin_path . '/workflows/variables/wc-order-shipping-postcode.php',
						'shipping_state'          => $this->starter_plugin_path . '/workflows/variables/wc-order-shipping-state.php',
						'status'                  => $this->starter_plugin_path . '/workflows/variables/wc-order-status.php',
						'subtotal'                => $this->starter_plugin_path . '/workflows/variables/wc-order-subtotal.php',
						'total'                   => $this->starter_plugin_path . '/workflows/variables/wc-order-total.php',
						'view_url'                => $this->starter_plugin_path . '/workflows/variables/wc-order-view-url.php',
					),
					'shop' => array(
						'title' => $this->starter_plugin_path . '/workflows/variables/shop-title.php',
						'url'   => $this->starter_plugin_path . '/workflows/variables/shop-url.php',
					)
				);
			}

			return $variables;
		}

		public function display_captcha( $form_data ) {
			?>
			<div class="flex border-b border-gray-100 ">
				<div class="w-2/5 mr-16">
					<div class="flex flex-row w-full">
						<div class="flex w-2/4">
							<div class="ml-4 mr-8 mr-4 pt-4 mb-2">
								<label for="tag-link"><span class="block ml-4 pr-4 text-sm font-medium text-gray-600 pb-2"><?php echo esc_html__( 'Enable Captcha' ); ?></span></label>
								<p class="italic text-xs text-gray-400 mt-2 ml-4 leading-snug pb-4"><?php echo esc_html__( 'Show a captcha to protect from bot signups.', 'email-subscribers' ); ?></p>
							</div>
						</div>
						<div class="flex">
							<div class="ml-16 mb-4 mr-4 mt-12">
								<label for="captcha" class=" inline-flex items-center cursor-pointer">
									<span class="relative">
										<input id="captcha" type="checkbox" class=" absolute es-check-toggle opacity-0 w-0 h-0" name="form_data[captcha]" value="yes" 
										<?php 
										if ( isset( $form_data['captcha'] ) && 'yes' === $form_data['captcha'] ) {
											echo 'checked="checked"';
										}

										?>
										 />

										<span class="es-mail-toggle-line"></span>
										<span class="es-mail-toggle-dot"></span>
									</span>
								</label>
							</div>
						</div>
					</div>
				</div>
			</div>
			<?php 
		}

		/**
		 * Register services in the starter version
		 * 
		 * @param array $services
		 * 
		 * @return array $services
		 * 
		 * @since 4.6.1
		 */
		public function register_services( $services = array() ) {

			$starter_services = array(
				'css_inliner',
				'es_cron',
			);
			
			$services = array_merge( $services, $starter_services );

			return $services;
		}

		/**
		 * Method to get plugin plan
		 * 
		 * @param string $plan
		 * 
		 * @return string $plan
		 * 
		 * @since 4.6.1
		 */
		public function get_plan( $plan = '' ) {

			$plan = 'starter';
			
			return $plan;
		}

		/**
		 * Disable session tracking when WC user optout during checkout
		 */
		public function ajax_disable_session_tracking() {
			check_ajax_referer( 'ig-es-public-nonce', 'security' );

			setcookie( 'ig_es_session_tracking_disabled', 'true', 0, '/' );

			do_action( 'ig_es_session_tracking_disabled' );

			wp_send_json_success();
		}

		/**
		 * Add action to pause/resume report
		 * 
		 * @param array $actions
		 * @param array $report
		 * 
		 * @since 4.7.8
		 */
		public function add_report_pause_resume_action( $actions = array(), $report = array() ) {

			$report_status = ! empty( $report['status'] ) ? $report['status'] : '';
			if ( IG_ES_MAILING_QUEUE_STATUS_SENDING === $report_status ) {
				$actions['pause'] = sprintf( '<a href="#" class="es-report-action pause" data-mailing-queue-id="%d">
				<svg fill="none" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" stroke="currentColor" viewBox="0 0 24 24" class="h-6 w-6 text-gray-500 ml-1 inline">
					<title>%s</title>
					<path d="M10 9v6m4-6v6m7-3a9 9 0 11-18 0 9 9 0 0118 0z"></path>
				</svg>
				</a>', esc_attr( $report['id'] ), esc_html__( 'Pause', 'email-subscribers' ) );
			} elseif ( IG_ES_MAILING_QUEUE_STATUS_PAUSED === $report_status ) {
				$actions['resume'] = sprintf( '<a href="#" class="es-report-action resume" data-mailing-queue-id="%d">
					<svg fill="none" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" stroke="currentColor" viewBox="0 0 24 24" class="h-6 w-6 text-blue-500 inline">
					<title>%s</title>
					<path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M14.752 11.168l-3.197-2.132A1 1 0 0010 9.87v4.263a1 1 0 001.555.832l3.197-2.132a1 1 0 000-1.664z" />
					<path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M21 12a9 9 0 11-18 0 9 9 0 0118 0z" />
				</svg>
				</a>', esc_attr( $report['id'] ), esc_html__( 'Resume', 'email-subscribers' ) );
			}

			return $actions;
		}

		/**
		 * Add broadcast pause/resume actions
		 * 
		 * @param array $campaign
		 * 
		 * @since 4.7.8
		 */
		public function add_broadcast_pause_resume_action( $campaign = array() ) {

			$campaign_id = ! empty( $campaign['id'] ) ? $campaign['id'] : 0;
			if ( ! empty( $campaign_id ) ) {
				$campaign_type = ES()->campaigns_db->get_campaign_type_by_id( $campaign_id );
				if ( 'newsletter' === $campaign_type ) {
					$campaign_status = ! empty( $campaign['status'] ) ? (int) $campaign['status'] : 0;
					$visiblity_class = IG_ES_CAMPAIGN_STATUS_QUEUED === $campaign_status ? '' : 'hidden';
					?>
					<a href="#" class="es-report-action pause <?php echo esc_attr( $visiblity_class ); ?>" data-campaign-id="<?php echo esc_attr( $campaign_id ); ?>">
						<svg fill="none" stroke-linecap="round" stroke-linejoin="round" stroke-width="2" stroke="currentColor" viewBox="0 0 24 24" class="h-6 w-6 text-gray-500 inline">
							<title><?php echo esc_html__( 'Pause campaign', 'email-subscribers' ); ?></title>
							<path d="M10 9v6m4-6v6m7-3a9 9 0 11-18 0 9 9 0 0118 0z"></path>
						</svg>
					</a>
					<?php
					$visiblity_class = IG_ES_CAMPAIGN_STATUS_PAUSED === $campaign_status ? '' : 'hidden';
					?>
					<a href="#" class="es-report-action resume <?php echo esc_attr( $visiblity_class ); ?>" data-campaign-id="<?php echo esc_attr( $campaign_id ); ?>">
						<svg xmlns="http://www.w3.org/2000/svg" class="h-6 w-6 text-blue-500 inline" fill="none" viewBox="0 0 24 24" stroke="currentColor">
							<title><?php echo esc_html__( 'Resume campaign', 'email-subscribers' ); ?></title>
							<path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M14.752 11.168l-3.197-2.132A1 1 0 0010 9.87v4.263a1 1 0 001.555.832l3.197-2.132a1 1 0 000-1.664z" />
							<path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M21 12a9 9 0 11-18 0 9 9 0 0118 0z" />
						</svg>
					</a>
					<?php
				}
			}
		}

		/**
		 * Pause/resume a campaign
		 * 
		 * @since 4.7.8
		 */
		public function pause_resume_report() {
			
			check_ajax_referer( 'ig-es-admin-ajax-nonce', 'security' );

			$campaign_id      = ig_es_get_request_data( 'campaign_id', 0 );
			$mailing_queue_id = ig_es_get_request_data( 'mailing_queue_id', 0 );
			$report_action    = ig_es_get_request_data( 'report_action', '' );
			$screen           = ig_es_get_request_data( 'screen', '' );

			if ( empty( $report_action ) ) {
				return;
			}

			$mailing_queue_hash = '';
			if ( ! empty( $campaign_id ) ) {
				$mailing_queue = ES_DB_Mailing_Queue::get_notification_by_campaign_id( $campaign_id );
				if ( ! empty( $mailing_queue ) ) {
					$mailing_queue_hash = $mailing_queue['hash'];
				}
			} elseif ( ! empty( $mailing_queue_id ) ) {
				$mailing_queue = ES_DB_Mailing_Queue::get_mailing_queue_by_id( $mailing_queue_id );
				if ( ! empty( $mailing_queue ) ) {
					$campaign_id        = $mailing_queue['campaign_id'];
					$mailing_queue_hash = $mailing_queue['hash'];
				}
			}

			$data = array();

			if ( ! empty( $campaign_id ) ) {
				$campaign = ES()->campaigns_db->get( $campaign_id );
				if ( ! empty( $campaign ) && 'newsletter' === $campaign['type'] ) {
					$campaign_status = 'pause' === $report_action ? IG_ES_CAMPAIGN_STATUS_PAUSED : IG_ES_CAMPAIGN_STATUS_QUEUED;
					ES()->campaigns_db->update_status( $campaign_id, $campaign_status );
				}
			}
			
			if ( ! empty( $mailing_queue_hash ) ) {
				$mailing_queue_status = 'pause' === $report_action ? IG_ES_MAILING_QUEUE_STATUS_PAUSED : IG_ES_MAILING_QUEUE_STATUS_SENDING;

				$status_updated = ES_DB_Mailing_Queue::update_sent_status( $mailing_queue_hash, $mailing_queue_status );

				if ( $status_updated ) {
					
					if ( 'campaign' === $screen ) {
						$campaigns_table    = ES_Campaigns_Table::get_instance();
						$campaign['status'] = $campaign_status;
						ob_start();
						$campaigns_table->column_status( $campaign );
						$data['status_html'] = ob_get_clean();
					} else {
						$reports                 = ES_Reports_Table::get_instance();
						$mailing_queue['status'] = $mailing_queue_status;
						$data['status_html']     = $reports->column_status( $mailing_queue );
					}

					wp_send_json_success( $data );
				} else {
					wp_send_json_error();
				}
			}
		}
	}

	new Email_Subscribers_Starter();
}
