<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Cart table. Can only be used with the cart.items variable
 *
 * Start-IG-Code
 * Override this template by copying it to yourtheme/woocommerce/email-subscribers/email/cart-table.php
 * End-IG-Code
 * 
 * Start-Woo-Code
 * Override this template by copying it to yourtheme/woocommerce/icegram-marketing-automation/email/cart-table.php
 * End-Woo-Code
 * 
 * @var array $cart_items
 * @var IG_ES_Cart $cart
 * @var ES_Workflow $workflow
 * @var string $variable_name
 * @var string $data_type
 * @var string $data_field
 */

$cart->calculate_totals();
$tax_display = get_option( 'woocommerce_tax_display_cart' );
$allowed_html_tags = ig_es_allowed_html_tags_in_esc();
?>

<?php if ( $cart->has_items() ) : ?>

	<table cellspacing="0" cellpadding="6" border="1" class="ig-es-cart-table">
		<thead>
		<tr>
			<th class="td" scope="col" colspan="2" style="text-align:left;"><?php echo esc_html__( 'Product', 'email-subscribers' ); ?></th>
			<th class="td" scope="col" style="text-align:left;"><?php echo esc_html__( 'Quantity', 'email-subscribers' ); ?></th>
			<th class="td" scope="col" style="text-align:left;"><?php echo esc_html__( 'Price', 'email-subscribers' ); ?></th>
		</tr>
		</thead>
		<tbody>

		<?php 
		foreach ( $cart->get_items() as $item ) :

			$product = $item->get_product();
			if ( ! $product ) {
				continue; // don't show items if there is no product
			}

			$line_total = 'excl' === $tax_display ? $item->get_line_subtotal() : $item->get_line_subtotal() + $item->get_line_subtotal_tax();

			?>

			<tr>
				<td width="115">
					<a href="<?php echo esc_url( $product->get_permalink() ); ?>">
						<?php
							$image_url = ig_es_get_wc_product_image_url( $product, 'thumbnail' );
						?>
						<img src="<?php echo esc_url( $image_url ); ?>" class="ig-es-product-image" alt="<?php echo esc_attr( $product->get_name() ); ?>">
					</a>
				</td>
				<td>
					<a href="<?php echo  esc_url( $product->get_permalink() ); ?>">
						<?php echo esc_html( $item->get_name() ); ?>
					</a>
					<?php echo wp_kses( $item->get_item_data_html( true ), $allowed_html_tags ); ?>
				</td>
				<td><?php echo esc_html( $item->get_quantity() ); ?></td>
				<td><?php echo wp_kses( $cart->price( $line_total ), $allowed_html_tags ); ?></td>
			</tr>

		<?php endforeach; ?>

		</tbody>

		<tfoot>

			<?php if ( $cart->has_coupons() ) : ?>
				<tr>
					<th scope="row" colspan="3">
						<?php echo esc_html__( 'Subtotal', 'email-subscribers' ); ?>
						<?php if ( 'excl' !== $tax_display ) : ?>
							<small><?php echo esc_html__( '(incl. tax)', 'email-subscribers' ); ?></small>
						<?php endif; ?>
					</th>
					<td><?php echo wp_kses( $cart->price( $cart->calculated_subtotal ), $allowed_html_tags ); ?></td>
				</tr>
			<?php endif; ?>

			<?php 
			foreach ( $cart->get_coupons() as $coupon_code => $coupon_data ) :

				$coupon_discount = 'excl' === $tax_display ? $coupon_data['discount_excl_tax'] : $coupon_data['discount_incl_tax'];
				?>

				<tr>
					<th scope="row" colspan="3">
						<?php
							/* translators: %s: Coupon code */
							echo esc_html__( sprintf( 'Coupon: %s', $coupon_code ), 'email-subscribers' );
						?>
					</th>
					<td><?php echo wp_kses( $cart->price( - $coupon_discount ), $allowed_html_tags ); ?></td>
				</tr>
			<?php endforeach; ?>

			<?php if ( $cart->needs_shipping() ) : ?>
				<tr>
					<th scope="row" colspan="3"><?php echo esc_html__( 'Shipping', 'email-subscribers' ); ?></th>
					<td><?php echo wp_kses( $cart->get_shipping_total_html(), $allowed_html_tags ); ?></td>
				</tr>
			<?php endif; ?>

			<?php 
			foreach ( $cart->get_fees() as $fee ) :
					$fee_amount = 'excl' === $tax_display ? $fee->amount : $fee->amount + $fee->tax;
				?>
				<tr>
					<th scope="row" colspan="3"><?php echo esc_html( $fee->name ); ?></th>
					<td><?php echo wp_kses( $cart->price( $fee_amount ), $allowed_html_tags ); ?></td>
				</tr>
			<?php endforeach; ?>

			<?php if ( wc_tax_enabled() && 'excl' === $tax_display ) : ?>
				<tr>
					<th scope="row" colspan="3"><?php echo esc_html__( 'Tax', 'email-subscribers' ); ?></th>
					<td><?php echo wp_kses( $cart->price( $cart->calculated_tax_total ), $allowed_html_tags ); ?></td>
				</tr>
			<?php endif; ?>

			<tr>
				<th scope="row" colspan="3">
					<?php echo esc_html__( 'Total', 'email-subscribers' ); ?>
					<?php if ( wc_tax_enabled() && 'excl' !== $tax_display ) : ?>
						<small>
							<?php
								/* translators: %s: Tax total */
								echo esc_html__( sprintf( '(includes %s tax)', $cart->price( $cart->calculated_tax_total ) ), 'email-subscribers' );
							?>
						</small>
					<?php endif; ?>
				</th>
				<td><?php echo wp_kses( $cart->price( $cart->calculated_total ), $allowed_html_tags ); ?></td>
			</tr>
		</tfoot>
	</table>

<?php endif; ?>
