<?php

defined( 'ABSPATH' ) || exit;

/***
 * ES_Trigger_Gravity_Forms_Submitted class.
 *
 * @since 4.4.1
 */
class ES_Trigger_Gravity_Forms_Submitted extends ES_Workflow_Trigger {

	/**
	 * Declares data items available in trigger.
	 *
	 * @var array
	 */
	public $supplied_data_items = array( 'gravity_forms_data' );

	/**
	 * Load trigger admin props.
	 */
	public function load_admin_details() {
		$this->title       = __( 'Gravity Form Submitted', 'email-subscribers' );
		$this->description = __( 'Fires whenever someone fill up Gravity Forms.', 'email-subscribers' );
		$this->group       = __( 'Form', 'email-subscribers' );
	}

	/**
	 * Load fields.
	 */
	public function load_fields() {

		$forms = array(
			0 => __( 'Any Forms', 'email-subscribers' ),
		);

		if ( class_exists( 'GFFormsModel' ) && method_exists( GFFormsModel::class, 'get_forms' ) ) {
			$gravity_forms_data = GFFormsModel::get_forms();

			if ( ! empty( $gravity_forms_data ) ) {

				foreach ( $gravity_forms_data as $form ) {
					$form_id    = $form->id;
					$form_title = $form->title;

					if ( ! empty( $form_id ) && ! empty( $form_title ) ) {

						if ( mb_strlen( $form_title ) > 25 ) {
							$form_title = mb_substr( $form_title, 0, 25 );
						}

						/* translators: %s: Gravity form ID. */
						$form_title = $form_title . ' ' . sprintf( esc_html__( '(ID: %s)', 'email-subscribers' ), $form_id );

						$forms[ $form_id ] = $form_title;
					}
				}
				$form_list_field = new ES_Select();
				$form_list_field->set_name( 'ig-es-form-id' );
				$form_list_field->set_title( __( 'Select Form', 'email-subscribers' ) );
				$form_list_field->set_options( $forms );
				$form_list_field->set_required();
				$this->add_field( $form_list_field );
			}
		}
	}

	/**
	 * Register trigger hooks.
	 */
	public function register_hooks() {
		add_action( 'gform_after_submission', array( $this, 'handle_gravity_form_submission' ), 20, 2 );
	}

	/**
	 * Catch Gravity Forms submission hook.
	 *
	 * @param $submission
	 * @param $form
	 */
	public function handle_gravity_form_submission( $submission, $form ) {

		if ( ! empty( $form['fields'] ) ) {

			$form_id = '';
			$email   = '';

			if ( ! empty( $submission['form_id'] ) ) {
				$form_id = $submission['form_id'];
			}

			// find email field & checkbox value.
			foreach ( $form['fields'] as $field ) {

				if ( 'email' === $field->type && ! empty( $submission[ $field->id ] ) ) {
					$email = $submission[ $field->id ];
					break;
				}
			}

			if ( ! empty( $email ) && ! empty( $form_id ) ) {

				$data = array(
					'gravity_forms_data' => array(
						'form_id' => $form_id,
						'email'   => $email,
					),
				);

				$this->maybe_run( $data );

			}
		}
	}


	/**
	 * Validate a workflow.
	 *
	 * @param ES_Workflow $workflow
	 *
	 * @return bool
	 */
	public function validate_workflow( $workflow ) {

		$gravity_forms_data = $workflow->data_layer()->get_item( 'gravity_forms_data' );

		if ( ! is_array( $gravity_forms_data ) || empty( $gravity_forms_data['email'] ) ) {
			return false;
		}

		$selected_form_id = $workflow->get_trigger_option( 'ig-es-form-id' );
		$selected_form_id = (int) $selected_form_id;

		$gravity_form_id = (int) $gravity_forms_data['form_id'];

		if ( ! empty( $selected_form_id ) && $selected_form_id !== $gravity_form_id ) {
			return false;
		}

		return true;
	}

}
