<?php

defined( 'ABSPATH' ) || exit;

/***
 * ES_Trigger_WPForms_Submitted class.
 *
 * @since 4.4.1
 */
class ES_Trigger_WPForms_Submitted extends ES_Workflow_Trigger {

	/**
	 * Declares data items available in trigger.
	 *
	 * @var array
	 */
	public $supplied_data_items = array( 'wpforms_data' );

	/**
	 * Load trigger admin props.
	 */
	public function load_admin_details() {
		$this->title       = __( 'WP Form Submitted', 'email-subscribers' );
		$this->description = __( 'Fires someone fill up WPForms.', 'email-subscribers' );
		$this->group       = __( 'Form', 'email-subscribers' );
	}

	/**
	 * Load form trigger fields.
	 */
	public function load_fields() {

		if ( class_exists( 'WPForms_Form_Handler' ) && method_exists( WPForms_Form_Handler::class, 'get' ) ) {

			$forms = array(
				0 => __( 'Any Forms', 'email-subscribers' ),
			);

			$wp_forms_instance = new WPForms_Form_Handler();

			$args = array(
				'post_status' => 'publish',
			);
			$id   = '';

			$wp_forms_data = $wp_forms_instance->get( $id, $args );

			if ( ! empty( $wp_forms_data ) ) {
				foreach ( $wp_forms_data as $form ) {

					$form_id    = $form->ID;
					$form_title = $form->post_title;

					if ( ! empty( $form_id ) && ! empty( $form_title ) ) {

						if ( mb_strlen( $form_title ) > 25 ) {
							$form_title = mb_substr( $form_title, 0, 25 );
						}

						/* translators: %s: WPForms form ID. */
						$form_title = $form_title . ' ' . sprintf( esc_html__( '(ID: %s)', 'email-subscribers' ), $form_id );

						$forms[ $form_id ] = $form_title;
					}
				}

				$form_list_field = new ES_Select();
				$form_list_field->set_name( 'ig-es-form-id' );
				$form_list_field->set_title( __( 'Select Form', 'email-subscribers' ) );
				$form_list_field->set_options( $forms );
				$form_list_field->set_required();
				$this->add_field( $form_list_field );
			}
		}

	}

	/**
	 * Register trigger hooks.
	 */
	public function register_hooks() {
		add_action( 'wpforms_process', array( $this, 'handle_wpform_submission' ), 20, 3 );
	}

	/**
	 * Catch WP Forms submission hook.
	 *
	 * @param $fields
	 * @param $entry
	 * @param $form_data
	 */
	public function handle_wpform_submission( $fields, $entry, $form_data ) {

		if ( ! empty( $fields ) ) {

			$form_id = '';
			$email   = '';
			$name    = '';

			foreach ( $fields as $field ) {
				if ( 'email' === $field['type'] ) {
					$email = $field['value'];
				} elseif ( 'name' === $field['type'] ) {
					$name = $field['value'];
				}
			}

			if ( ! empty( $entry['id'] ) ) {
				$form_id = $entry['id'];
			}

			if ( ! empty( $email ) ) {

				$data = array(
					'wpforms_data' => array(
						'form_id' => $form_id,
						'email'   => $email,
						'name'    => $name,
					),
				);

				$this->maybe_run( $data );
			}
		}
	}


	/**
	 * Validate a workflow.
	 *
	 * @param ES_Workflow $workflow
	 *
	 * @return bool
	 */
	public function validate_workflow( $workflow ) {

		$wpforms_data = $workflow->data_layer()->get_item( 'wpforms_data' );

		if ( ! is_array( $wpforms_data ) || empty( $wpforms_data['email'] ) ) {
			return false;
		}

		$selected_form_id = $workflow->get_trigger_option( 'ig-es-form-id' );
		$selected_form_id = (int) $selected_form_id;
		$wpforms_id       = (int) $wpforms_data['form_id'];

		if ( ! empty( $selected_form_id ) && $selected_form_id !== $wpforms_id ) {
			return false;
		}

		return true;
	}

}
