<?php

// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Variable Abstract Product Display Class.
 *
 * @since 4.6.9
 *
 */
abstract class IG_ES_Variable_Abstract_Product_Display extends IG_ES_Workflow_Variable {

	public $supports_cart_table = false;

	protected $temp_template_args = array();

	/**
	 * Load admin details
	 */
	public function load_admin_details() {

		$templates = apply_filters( 'ig_es_variables_product_templates', array(
			'cart-table'             => __( 'Cart Table', 'email-subscribers' ),
			'product-grid-2-col.php' => __( 'Product Grid - 2 Column', 'email-subscribers' ),
		));

		if ( ! $this->supports_cart_table ) {
			unset( $templates[ 'cart-table' ] );
		}

		$this->add_parameter_select_field( 'template', __( 'Select which template will be used to display the products.', 'email-subscribers' ), $templates );

		$this->add_parameter_text_field( 'url_append', __( "Add a string to the end of each product URL. For example, using '#tab-reviews' can link customers directly to the review tab on a product page.", 'email-subscribers'), false );
	}

	/**
	 * Get default arguements for product templates
	 * 
	 * @param $workflow Workflow
	 * @param array $parameters
	 * @return array
	 */
	public function get_default_product_template_args( $workflow, $parameters = array() ) {
		return array(
			'workflow'      => $workflow,
			'variable_name' => $this->get_name(),
			'data_type'     => $this->get_data_type(),
			'data_field'    => $this->get_data_field(),
			'url_append'    => isset( $parameters['url_append'] ) ? trim( ES_Clean::string( $parameters['url_append'] ) ) : '',
		);
	}


	/**
	 * Get products' display HTML
	 * 
	 * @param string $template
	 * @param array $args
	 *
	 * @return string
	 */
	public function get_product_display_html( $template, $args = array() ) {

		ob_start();

		if ( $template ) {
			$template = sanitize_file_name( $template );

			if ( ! pathinfo( $template, PATHINFO_EXTENSION ) ) {
				$template .= '.php';
			}
		} else {
			$template = 'cart-table.php';
		}

		$this->temp_template_args = $args;
		add_filter( 'post_type_link', array( $this, 'filter_product_links' ), 100, 2 );

		// Start-Woo-Code.
		$template_path = 'woocommerce/icegram-marketing-automation';
		// End-Woo-Code.
		
		// Start-IG-Code.
		$template_path = 'woocommerce/email-subscribers';
		// End-IG-Code.

		$default_path = ES_PLUGIN_DIR . 'starter/workflows/templates/woocommerce/';

		wc_get_template( 'email/' . $template, $args, $template_path, $default_path );

		remove_filter( 'post_type_link', array( $this, 'filter_product_links' ) );
		$this->temp_template_args = array();

		return ob_get_clean();
	}


	/**
	 * Add url append arguement to product links
	 * 
	 * @param string $link
	 * @param WP_Post $post
	 * @return string
	 */
	public function filter_product_links( $link, $post ) {

		if ( 'product' !== $post->post_type ) {
			return $link;
		}

		if ( isset( $this->temp_template_args['url_append'] ) ) {
			$link .= $this->temp_template_args['url_append'];
		}
		return $link;
	}

}
