<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Variable class to get value for {{wc_order.billing_country}} placeholder
 */
class IG_ES_Variable_Order_Billing_Country extends IG_ES_Workflow_Variable {

	/**
	 * Load description and parameters for variable in admin screen.
	 */
	public function load_admin_details() {
		$this->description = __( 'Displays the billing country for the order.', 'email-subscribers' );

		$this->add_parameter_select_field(
			'format',
			__( 'Choose whether to display the abbreviation or full name of the country.', 'email-subscribers' ),
			array(
				''             => __( 'Full', 'email-subscribers' ),
				'abbreviation' => __( 'Abbreviation', 'email-subscribers' ),
			),
			false
		);
	}


	/**
	 * Get country name.
	 *
	 * @param WC_Order $order
	 * @param array     $parameters
	 *
	 * @return string $return
	 */
	public function get_value( $order, $parameters ) {

		$format = isset( $parameters['format'] ) ? $parameters['format'] : 'full';

		$return = null;

		switch ( $format ) {
			case 'full':
				$return = ig_es_get_country_name( $order->get_billing_country() );
				break;
			case 'abbreviation':
				$return = $order->get_billing_country();
				break;
		}

		return $return;
	}
}

return new IG_ES_Variable_Order_Billing_Country();
