<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Variable class to get value for {{wc_order.billing_state}} placeholder
 */
class IG_ES_Variable_Order_Billing_State extends IG_ES_Workflow_Variable {

	/**
	 * Load description and parameters for variable in admin screen.
	 */
	public function load_admin_details() {
		parent::load_admin_details();
		$this->description = __( 'Displays the billing state for the order.', 'email-subscribers' );
		$this->add_parameter_select_field(
			'format', __( 'Choose whether to display the abbreviation or full name of the state.', 'email-subscribers' ),
			array(
				'' => __( 'Full', 'email-subscribers' ),
				'abbreviation' => __( 'Abbreviation', 'email-subscribers' ),
			),
			false
		);
	}


	/**
	 * Returns the state name or abbreviation.
	 *
	 * @param WC_Order $order
	 * @param array     $parameters
	 * @param IG_ES_Workflow  $workflow
	 *
	 * @return string
	 */
	public function get_value( $order, $parameters, $workflow ) {
		$format  = isset( $parameters['format'] ) ? $parameters['format'] : 'full';
		$state   = $order->get_billing_state();
		$country = $order->get_billing_country();
		$return  = null;

		switch ( $format ) {
			case 'full':
				$return = ig_es_get_state_name( $country, $state );
				break;
			case 'abbreviation':
				$return = $state;
				break;
		}

		return $return;
	}
}

return new IG_ES_Variable_Order_Billing_State();
